==> enterprisemodules-wls_config-3.7.1.tar.gz: enterprisemodules-wls_config-3.7.1/lib/puppet/type/wls_datasource/xaproperties.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:xaproperties, :array_matching => :all, :parent => Puppet::Parameter::WlsHashProperty) do

  desc <<-EOD
    Datasource XA properties.

    Here is an example that uses `xaproperties`:

        wls_datasource { 'jmsDS':
          ensure                     => 'present',
          drivername                 => 'com.mysql.jdbc.Driver',
          globaltransactionsprotocol => 'None',
          initialcapacity            => 1,,
          jndinames                  => ['jmsDS'],
          maxcapacity                => '15',
          mincapacity                => 1,,
          statementcachesize         => '10',
          testconnectionsonreserve   => '0',
          target                     => ['WebCluster'],
          targettype                 => ['Cluster'],
          testtablename              => 'SQL SELECT 1',
          url                        => 'jdbc:mysql://10.10.10.10:3306/jms',
          user                       => 'jms',
          password                   => 'pass',
          usexa                      => 1,
          xaproperties               => ['RollbackLocalTxUponConnClose=0', 'RecoverOnlyOnce=0', 'KeepLogicalConnOpenOnRelease=0', 'KeepXaConnTillTxComplete=1', 'XaTransactionTimeout=14400', 'XaRetryIntervalSeconds=60', 'XaRetryDurationSeconds=0', 'ResourceHealthMonitoring=1', 'NewXaConnForCommit=0', 'XaSetTransactionTimeout=1', 'XaEndOnlyOnce=0', 'NeedTxCtxOnClose=0'],
          # To Optionally Configure as Gridlink Datasource
          fanenabled                 => 1,,
          onsnodelist                => '10.10.10.110:6200,10.10.10.111:6200',
        }

    `xaproperties` are case sensitive and should be provided as an array containing **all** values. Use WLST
    and run ls() in the JDBCXAParams component of your datasource to determine the valid XA properties which
    can be set, or use puppet resource wls_datasource

  EOD

  data_type("Optional[Variant[String,Array[String]]]")

  maps_to('JDBCResource/%{datasource_name}/JDBCXAParams/%{datasource_name}')

  to_translate_to_resource do |raw_resource, resource|
    wls_config = Puppet_X::EnterpriseModules::WebLogic::Tree.new(raw_resource[:domain])
    xa_properties = wls_config.properties(actual_path(raw_resource))
    xa_properties.collect do | property|
      value = wls_config.get("#{actual_path(raw_resource)}/#{property}")
      "#{property}=#{value}"
    end
  end

  on_apply do
    if resource[:usexa] == 1
      wls_config.execute(template("wls_config/wls_datasource/set_xaproperties.py.erb", binding))
    else
      fail 'You specified XA properties, but have not set the usexa parameter'
    end
  end

end

def xaproperties
  self[:xaproperties] ? self[:xaproperties].join(',') : ''
end

==> enterprisemodules-wls_config-3.15.0.tar.gz: enterprisemodules-wls_config-3.15.0/lib/puppet/type/wls_datasource/xaproperties.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:xaproperties, :array_matching => :all, :parent => Puppet::Parameter::WlsHashProperty) do
  desc <<-DESC
    Datasource XA properties.

    Here is an example that uses `xaproperties`:

        wls_datasource { 'jmsDS':
          ensure                     => 'present',
          drivername                 => 'com.mysql.jdbc.Driver',
          globaltransactionsprotocol => 'None',
          initialcapacity            => 1,,
          jndinames                  => ['jmsDS'],
          maxcapacity                => '15',
          mincapacity                => 1,,
          statementcachesize         => '10',
          testconnectionsonreserve   => '0',
          target                     => ['WebCluster'],
          targettype                 => ['Cluster'],
          testtablename              => 'SQL SELECT 1',
          url                        => 'jdbc:mysql://10.10.10.10:3306/jms',
          user                       => 'jms',
          password                   => 'pass',
          usexa                      => 1,
          xaproperties               => ['RollbackLocalTxUponConnClose=0', 'RecoverOnlyOnce=0', 'KeepLogicalConnOpenOnRelease=0', 'KeepXaConnTillTxComplete=1', 'XaTransactionTimeout=14400', 'XaRetryIntervalSeconds=60', 'XaRetryDurationSeconds=0', 'ResourceHealthMonitoring=1', 'NewXaConnForCommit=0', 'XaSetTransactionTimeout=1', 'XaEndOnlyOnce=0', 'NeedTxCtxOnClose=0'],
          # To Optionally Configure as Gridlink Datasource
          fanenabled                 => 1,,
          onsnodelist                => '10.10.10.110:6200,10.10.10.111:6200',
        }

    `xaproperties` are case sensitive and should be provided as an array containing **all** values. Use WLST
    and run ls() in the JDBCXAParams component of your datasource to determine the valid XA properties which
    can be set, or use puppet resource wls_datasource

  DESC

  data_type('Optional[Variant[String,Array[String]]]')

  maps_to('JDBCResource/%<datasource_name>s/JDBCXAParams/%<datasource_name>s')

  to_translate_to_resource do |raw_resource, _resource|
    wls_config = Puppet_X::EnterpriseModules::WebLogic::Tree.new(raw_resource[:domain])
    xa_properties = wls_config.properties(actual_path(raw_resource))
    xa_properties.collect do |property|
      value = wls_config.get("#{actual_path(raw_resource)}/#{property}")
      "#{property}=#{value}"
    end
  end

  on_apply do
    fail 'You specified XA properties, but have not set the usexa parameter' unless resource[:usexa] == 1

    wls_config.execute(template('wls_config/wls_datasource/set_xaproperties.py.erb', binding))
  end
end

def xaproperties
  self[:xaproperties] ? self[:xaproperties].join(',') : ''
end
